=========================
DP-XGBoost Python Package
=========================

|PyPI version|

Installation
============

From `PyPI <https://pypi.python.org/pypi/dp-xgboost>`_
------------------------------------------------------

For a stable version, install using ``pip``::

    pip install dp-xgboost

.. |PyPI version| image:: https://badge.fury.io/py/dp-xgboost.svg
   :target: http://badge.fury.io/py/dp-xgboost

For building from source, see https://github.com/sarus-tech/dp-xgboost.
